@@ -8,13 +8,9 @@ use warnings FATAL => 'all';
 
 Dancer::Plugin::Database::Core - Shared core for D1 and D2 Database plugins
 
-=head1 VERSION
-
-Version 0.10
-
 =cut
 
-our $VERSION = '0.10';
+our $VERSION = '0.12';
 
 my %handles;
 # Hashref used as key for default handle, so we don't have a magic value that
@@ -193,6 +189,12 @@ sub _get_settings {
 sub _get_connection {
     my ($settings, $logger, $hook_exec) = @_;
 
+    if (!$settings->{dsn} && !$settings->{driver}) {
+        die "Can't get a database connection without settings supplied!\n"
+            . "Please check you've supplied settings in config as per the "
+            . "Dancer::Plugin::Database documentation";
+    }
+
     # Assemble the DSN:
     my $dsn = '';
     my $driver = '';
@@ -287,8 +289,11 @@ sub _get_connection {
     # ("You can stash private data into DBI handles via $h->{private_..._*}..")
     $dbh->{private_dancer_plugin_database} = {
         log_queries => $settings->{log_queries} || 0,
+        logger      => $logger,
     };
 
+
+
     # Re-bless it as a Dancer::Plugin::Database::Core::Handle object, to provide nice
     # extra features (unless the config specifies a different class; if it does,
     # this should be a subclass of Dancer::Plugin::Database::Core::Handle in order to
